@@ -4,7 +4,7 @@ import subprocess
 import sys
 import time
 from functools import lru_cache
-from typing import Dict, List, Union
+from typing import Dict, List
 
 import boto3
 from sceptre.cli.helpers import setup_logging
@@ -123,6 +123,24 @@ class RemoteDockerClient:
         logger.warning("Stopping instance")
         return self.ec2_client.stop_instances(InstanceIds=[self.get_instance_id()])
 
+    def _set_disable_api_termination(self, value: bool):
+        return self.ec2_client.modify_instance_attribute(
+            DisableApiTermination=dict(Value=value), InstanceId=self.get_instance_id(),
+        )
+
+    def enable_termination_protection(self):
+        logger.warning("Enabling Termination protection")
+        return self._set_disable_api_termination(True)
+
+    def disable_termination_protection(self):
+        logger.warning("Disabling Termination protection")
+        return self._set_disable_api_termination(False)
+
+    def is_termination_protection_enabled(self):
+        return self.ec2_client.describe_instance_attribute(
+            Attribute="disableApiTermination", InstanceId=self.get_instance_id(),
+        )["DisableApiTermination"]["Value"]
+
     def start_tunnel(
         self, *, extra_local_forwards=None, extra_remote_forwards=None,
     ):
@@ -134,10 +152,10 @@ class RemoteDockerClient:
         remote_forwards = dict(self.remote_forwards, **extra_remote_forwards)
 
         ip = self.get_ip()
-        cmd_s = f"""
-        sudo ssh -v -o StrictHostKeyChecking=no -o "ServerAliveInterval=60" -N -T
-         -i {self.ssh_key_path} {INSTANCE_USERNAME}@{ip}
-        """
+        cmd_s = (
+            'sudo ssh -v -o StrictHostKeyChecking=no -o "ServerAliveInterval=60" -N -T'
+            f" -i {self.ssh_key_path} {INSTANCE_USERNAME}@{ip}"
+        )
 
         for port_from, port_to in DOCKER_PORT_FORWARD.items():
             cmd_s += f" -L localhost:{port_from}:localhost:{port_to}"
@@ -212,15 +230,6 @@ class RemoteDockerClient:
         logger.warning("Starting bootstrap")
         self.bootstrap_instance()
 
-    def update_instance(self) -> Dict:
-        logger.warning("Updating instance")
-        result = self._get_sceptre_plan().update()
-
-        logger.debug("Got sceptre result: %s", result)
-        if "complete" not in result.values():
-            raise Exception(f"sceptre command failed: {list(result.values())}")
-        return result
-
     def delete_instance(self) -> Dict:
         logger.warning("Deleting instance")
         result = self._get_sceptre_plan().delete()
@@ -234,10 +243,10 @@ class RemoteDockerClient:
         ssh_cmd = ssh_cmd if ssh_cmd else ""
         options = options if options else ""
 
-        cmd_s = f"""
-        ssh -o StrictHostKeyChecking=no -i {self.ssh_key_path}
-        {options} {INSTANCE_USERNAME}@{self.get_ip()} {ssh_cmd}
-        """
+        cmd_s = (
+            f"ssh -o StrictHostKeyChecking=no -i {self.ssh_key_path}"
+            f" {options} {INSTANCE_USERNAME}@{self.get_ip()} {ssh_cmd}"
+        )
 
         return shlex.split(cmd_s)
 
@@ -297,8 +306,7 @@ class RemoteDockerClient:
         sync_paths: List[str],
         force: bool = False,
         repeat_watch: bool = False,
-        return_as_str: bool = False,
-    ) -> Union[str, List[str]]:
+    ) -> List[str]:
         cmd_s = (
             f"unison-gitignore {replica_path} 'ssh://{INSTANCE_USERNAME}@{ip}/{replica_path}'"
             f" -prefer {replica_path} -batch -sshargs '-i {self.ssh_key_path}'"
@@ -317,9 +325,7 @@ class RemoteDockerClient:
         if repeat_watch:
             cmd_s += " -repeat watch"
 
-        if return_as_str:
-            return cmd_s
-        return shlex.split(cmd_s)
+        return shlex.split(cmd_s.replace("\n", ""))
 
     def sync(
         self, *, extra_sync_dirs: List[str] = None,
@@ -344,14 +350,9 @@ class RemoteDockerClient:
         logger.info("Pushing local files to remote server")
         subprocess.run(
             self._get_unison_cmd(
-                ip=ip,
-                replica_path=replica_path,
-                sync_paths=sync_paths,
-                force=True,
-                return_as_str=True,
+                ip=ip, replica_path=replica_path, sync_paths=sync_paths, force=True,
             ),
             check=True,
-            shell=True,
         )
 
         # Then watch for update
